# Static-sitemap

## How to use

```sh
# install
python -m pip install static_sitemap

python -m static_sitemap https://my-static-website.com
```

## Options

- `--verbose` : Display URLs
- `--quiet` : Display Nothing
- `--sitemap` : Create a `sitemap.xml` file
- `--rmError` : Delete incorrect link in the arra
- `--css` : check css file (useless)
- `--json` : check json file (useless)
- `--html` : to display the html from requests

## Others files

- `other.html` is useless
